<?php

namespace Tests;

use Orchestra\Testbench\TestCase;

abstract class BaseTestCase extends TestCase
{
    protected function getPackageProviders($app)
    {
        return [
            // Provides configuration (reads config/logme.php and exposes it via config() function
            'Buckhill\LogMe\Provider\LogMeProvider',

            // Provides ElasticSearch client (official php package)
            'Buckhill\LogMe\Provider\ElasticSearchClient',

        ];
    }
}