<?php

return [
    /*
    |--------------------------------------------------------------------------
    | Custom Elasticsearch Client Configuration
    |--------------------------------------------------------------------------
    |
    | This array will be passed to the Elasticsearch client.
    | See configuration options here:
    |
    | http://www.elasticsearch.org/guide/en/elasticsearch/client/php-api/current/_configuration.html
    */

    'hosts'     => [env('ELASTICSEARCH_URL', 'localhost:9200')],
    'retries'   => env('ELASTICSEARCH_RETRIES', 1),
    'default_index' => env('DEFAULT_INDEX', 'logme'),
    'log'       => [
        'enabled' => false,
        'filename' => 'elasticsearch.log'
    ]
];