<?php

namespace Buckhill\LogMe\Facades;

use Illuminate\Support\Facades\Facade;

class ElasticSearchBuilder extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'ElasticSearchBuilder';
    }
}