<?php

namespace Tests\Feature;

use Tests\BaseTestCase;

class LogMeTest extends BaseTestCase
{
    public function testLogMe()
    {
        $result = logme('This is a test message', 'log', 'logs');

        $this->assertTrue(is_array($result));
    }
}